Demonstration Jupyter notebooks
===============================

There are a number of demonstration `Jupyter Notebooks <http://jupyter.org/>`_
available to help you get started with satsense. They can be found in the
`notebooks folder of our github repository <https://github.com/DynaSlum/satsense/tree/master/notebooks>`_.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   feature_extraction
